==> moodle-1.4.3-pgsql.tgz: moodle/lang/cs/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.4 (2004083100)


$string['addanewdiscussion'] = 'Pidat nov pspvek';
$string['addanewtopic'] = 'Pidat nov tma';
$string['allowchoice'] = 'Umonit vbr komukoliv';
$string['allowdiscussions'] = 'Me $a pispvat do tohoto fra?';
$string['allowratings'] = 'Umonit hodnocen pspvk?';
$string['allowsdiscussions'] = 'V tomto fru me kad zahjit nov tma diskuse.';
$string['anyfile'] = 'Libovoln soubor';
$string['attachment'] = 'Ploha';
$string['bynameondate'] = 'autor $a->name - $a->date';
$string['configdisplaymode'] = 'Pedvolen zpsob zobrazovn diskuse, nen-li eeno jinak.';
$string['configenablerssfeeds'] = 'Tmto povolte funkci RSS kanl pro vechna diskusn fra. Budete jet muset zapnout RSS kanly v nastaven jednotlivch frech.';
$string['configlongpost'] = 'Pspvek del ne tato vloen hodnota (HTML kd se nepot) je povaovn za dlouh.';
$string['configmanydiscussions'] = 'Maximln poet diskus vo fru zobrazovan na jedn strnce.';
$string['configmaxbytes'] = 'Vchoz maximln velikost plohy ve vech frech na tchto strnkch (me bt upravena nastavenm kurzu a dalmi loklnmi promnnmi)';
$string['configreplytouser'] = 'Kdy je pspvek odesln odbratelm, m email v poli Od: obsahovat adresu autora pspvku? Pjemce tak me odpovdat pmo autorovi emailem a ne pes diskusn frum. I kdy je zde zvolena hodnota \'Ano\', uivatel si mohou ve svch profilech nastavit skrvn svm emailov adresy.';
$string['configshortpost'] = 'Pspvek krat ne tato vloen hodnota (HTML kd se nepot) je povaovn za krtk.';
$string['couldnotadd'] = 'Neznm chyba! Nemohu pidat v pspvek';
$string['couldnotdeleteratings'] = 'Je mi lto, ji ohodnocen pspvek neme bt odstrann';
$string['couldnotdeletereplies'] = 'Je mi lto, pspvek, na kter ji bylo odpovzeno, neme bt odstrann';
$string['couldnotupdate'] = 'Neznm chyba! Nemohu aktualizovat v pspvek';
$string['delete'] = 'Odstranit';
$string['deleteddiscussion'] = 'Tma diskuse bylo odstranno';
$string['deletedpost'] = 'Pspvek byl odstrann';
$string['deletesure'] = 'Jste si jist, e chcete odstranit tento pspvek?';
$string['digestmailheader'] = 'Toto je vas denni souhrn novych prispevku v diskusich na strankach $a->sitename. Chcete-li zmenit nastaveni techto odberu, jdete na $a->userprefs.';
$string['digestmailprefs'] = 'vas uzivatelsky profil';
$string['digestmailsubject'] = '$a: souhrn novych prispevku';
$string['digestsentusers'] = 'Souhrnn emaily spn zaslny $a uivatelm.';
$string['discussion'] = 'Diskuse';
$string['discussionmoved'] = 'Tato diskuse byla pesunuta do \'$a\'.';
$string['discussionname'] = 'Nzev diskuse';
$string['discussions'] = 'Diskuse';
$string['discussionsstartedby'] = 'Diskusi zahjil(a) $a';
$string['discussionsstartedbyrecent'] = 'Diskusi prv zahjil(a) $a';
$string['discussthistopic'] = 'Zobrazit diskusi';
$string['eachuserforum'] = 'Kad me zahjit jedno tma diskuse';
$string['edit'] = 'Upravit';
$string['editing'] = 'prava';
$string['emptymessage'] = 'Ve vaem pspvku je nco patn. Mon jste nevyplnili nkter povinn daje, nebo piloen soubor byl moc velk.  Vae pravy NEBYLY ULOENY!';
$string['everyonecanchoose'] = 'Kdokoliv si me vybrat odebrn pspvk emailem';
$string['everyoneissubscribed'] = 'Vichni odebraj nov pspvky emailem';
$string['existingsubscribers'] = 'Stvajc odbratel';
$string['forcesubscribe'] = 'Vnutit vem odebrn pspvk emailem';
$string['forcesubscribeq'] = 'Vnutit vem odebrn pspvk emailem?';
$string['forum'] = 'Frum';
$string['forumintro'] = 'vod do diskusnho fra';
$string['forumname'] = 'Nzev fra';
$string['forums'] = 'Fra';
$string['forumtype'] = 'Typ fra';
$string['generalforum'] = 'Bn frum pro obecn pouit';
$string['generalforums'] = 'Obecn fra';
$string['inforum'] = 'v $a';
$string['intronews'] = 'Novinky a oznmen';
$string['introsocial'] = 'Oteven frum pro pokec o emkoliv chcete';
$string['introteacher'] = 'Uzaven frum pro uitele kurzu';
$string['lastpost'] = 'Posledn pspvek';
$string['learningforums'] = 'Uebn fra';
$string['maxattachmentsize'] = 'Maximln velikost plohy';
$string['maxtimehaspassed'] = 'Je mi lto, vyprel asov limit pro pravu pspvku $a';
$string['message'] = 'Zprva';
$string['modeflatnewestfirst'] = 'Zobrazit odpovdi za sebou (prvn nejnovj)';
$string['modeflatoldestfirst'] = 'Zobrazit odpovdi za sebou (prvn nejstar)';
$string['modenested'] = 'Zobrazit hierarchii odpovd (vetn textu)';
$string['modethreaded'] = 'Zobrazit hierarchii odpovd (pouze osnovu)';
$string['modulename'] = 'Frum';
$string['modulenameplural'] = 'Fra';
$string['more'] = 'vce';
$string['movethisdiscussionto'] = 'Pesunout tuto diskusi do ...';
$string['namenews'] = 'Novinky';
$string['namesocial'] = 'Spolen frum';
$string['nameteacher'] = 'Uitelsk frum';
$string['newforumposts'] = 'Nov pspvky';
$string['nodiscussions'] = 'V tomto fru zatm nejsou dn tmata diskuse';
$string['noguestpost'] = 'Je mi lto, host nemohou pispvat do diskuse';
$string['nomorepostscontaining'] = 'Nebyly nalezeny dn dal pspvky obsahujc \'$a\'';
$string['nonews'] = 'Dosud nebyly vloeny dn novinky';
$string['noposts'] = 'Bez pspvk';
$string['nopostscontaining'] = 'Nebyly nalezeny dn pspvky obsahujc \'$a\'';
$string['nosubscribers'] = 'V tomto fru zatm nikdo neodebr nov pspvky emailem';
$string['notingroup'] = 'Je mi lto, ale pro prohlen tohoto fra muste bt lenem skupiny.';
$string['nownotsubscribed'] = '$a->name NEBUDE dostvat emailem kopie pspvk z \'$a->forum\'.';
$string['nowsubscribed'] = '$a->name nyn bude dostvat emailem kopie pspvk z \'$a->forum\'.';
$string['numposts'] = '$a pspvk';
$string['olderdiscussions'] = 'Star diskuse';
$string['openmode0'] = 'Ani nov tmata diskuse, ani odpovdi nejsou povoleny';
$string['openmode1'] = 'Bez tmat diskuse, ale odpovdi jsou povoleny';
$string['openmode2'] = 'Nov tmata diskuse i odpovdi jsou povoleny';
$string['parent'] = 'Ukzat pedchdce';
$string['parentofthispost'] = 'Pedchdce tohoto pspvku';
$string['postadded'] = 'V pspvek byl spn pidn.<P>Na ppadn pravy mte $a .';
$string['postincontext'] = 'Ukzat pspvek v kontextu';
$string['postmailinfo'] = 'Toto je kopie nove zpravy ze stranek $a .
Chcete-li na prispevek odpovedet, nasledujte tento odkaz:';
$string['postrating1'] = 'Vykazuje zejmna INDIVIDULN poznvn';
$string['postrating2'] = 'Rovnomrn samostatn i kolektivn';
$string['postrating3'] = 'Vykazuje zejmna KOLEKTIVN poznvn';
$string['posts'] = 'Pspvky';
$string['posttoforum'] = 'Poslat do fra';
$string['postupdated'] = 'V pspvek byl aktualizovn';
$string['potentialsubscribers'] = 'Odbratel k dispozici';
$string['processingdigest'] = 'Zpracovvm souhrnn email pro uivatele $a';
$string['processingpost'] = 'Zpracovvm pspvek $a';
$string['prune'] = 'Oddlit';
$string['prunedpost'] = 'Z pspvku byla vytvoena nov diskuse';
$string['pruneheading'] = 'Oddlit a pesunout tento pspvek do nov diskuse.';
$string['rate'] = 'Hodnotit';
$string['rating'] = 'Hodnocen';
$string['ratingeveryone'] = 'Kdokoliv me hodnotit pspvky';
$string['ratingno'] = 'Bez hodnocen';
$string['ratingonlyteachers'] = 'Pouze \'$a\' me hodnotit pspvky';
$string['ratingpublic'] = '$a mohou vidt libovoln hodnocen';
$string['ratingpublicnot'] = '$a mohou vidt jen sv hodnocen';
$string['ratings'] = 'Hodnocen';
$string['ratingssaved'] = 'Hodnocen uloeno';
$string['ratingsuse'] = 'Pout hodnocen';
$string['ratingtime'] = 'Omezit hodnocen na pspvky s datumy v tomto rozsahu:';
$string['re'] = 'Re:';
$string['readtherest'] = 'st zbytek tohoto tmatu';
$string['replies'] = 'Odpovdi';
$string['repliesmany'] = '$a odpovd';
$string['repliesone'] = '$a odpov';
$string['reply'] = 'Odpovdt';
$string['replyforum'] = 'Odpovdt do fra';
$string['rsssubscriberssdiscussions'] = 'Zobrazit RSS kanl \'$a\' diskus';
$string['rsssubscriberssposts'] = 'Zobrazit RSS kanl \'$a\' pspvk';
$string['search'] = 'Hledat';
$string['searchforums'] = 'Prohledat fra';
$string['searcholderposts'] = 'Prohledat star pspvky...';
$string['searchresults'] = 'Vsledky hledn';
$string['sendinratings'] = 'Odeslat m posledn hodnocen';
$string['showsubscribers'] = 'Ukzat odbratele';
$string['singleforum'] = 'Prost diskuse';
$string['startedby'] = 'Zahjena';
$string['subject'] = 'Pedmt';
$string['subscribe'] = 'Odebrat nov pspvky emailem';
$string['subscribeall'] = 'Nastavit vem odebrn pspvku emailem';
$string['subscribed'] = 'Pspvky odebrny emailem';
$string['subscribenone'] = 'Odebrat vem odebrn pspvk emailem';
$string['subscribers'] = 'Odbratel';
$string['subscribersto'] = 'Odbratel - \'$a\'';
$string['subscribestart'] = 'Poslej mi emailem kopie pspvk v tomto fru';
$string['subscribestop'] = 'Nechci dostvat emailem kopie pspvk v tomto fru';
$string['subscription'] = 'Odebrn';
$string['subscriptions'] = 'Odebrn';
$string['unsubscribe'] = 'Neodebrat pspvky z tohoto fra emailem';
$string['unsubscribed'] = 'Neodebrno';
$string['unsubscribeshort'] = 'Neodebrat';
$string['yesforever'] = 'Ano, navdy';
$string['yesinitially'] = 'Ano, na zatku';
$string['youratedthis'] = 'Ji jste hodnotili';
$string['yournewtopic'] = 'Vae nov tma diskuse';
$string['yourreply'] = 'Vae odpov';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/cs/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.6 development (2005052400)


$string['addanewdiscussion'] = 'Pidat nov pspvek';
$string['addanewtopic'] = 'Pidat nov tma';
$string['advancedsearch'] = 'Pokroil vyhledvn';
$string['allforums'] = 'Vechna fra';
$string['allowchoice'] = 'Umonit vbr komukoliv';
$string['allowdiscussions'] = 'Me $a pispvat do tohoto fra?';
$string['allowratings'] = 'Umonit hodnocen pspvk?';
$string['allowsdiscussions'] = 'V tomto fru me kad zahjit nov tma diskuse.';
$string['anyfile'] = 'Libovoln soubor';
$string['attachment'] = 'Ploha';
$string['bynameondate'] = 'autor $a->name - $a->date';
$string['configcleanreadtime'] = 'V kterou denn hodinu se m istit tabulka \'read\' od starch pspvk?';
$string['configdisplaymode'] = 'Pedvolen zpsob zobrazovn diskuse, nen-li eeno jinak.';
$string['configenablerssfeeds'] = 'Tmto povolte funkci RSS kanl pro vechna diskusn fra. Budete jet muset zapnout RSS kanly v nastaven jednotlivch frech.';
$string['configlongpost'] = 'Pspvek del ne tato vloen hodnota (HTML kd se nepot) je povaovn za dlouh.';
$string['configmanydiscussions'] = 'Maximln poet diskus vo fru zobrazovan na jedn strnce.';
$string['configmaxbytes'] = 'Vchoz maximln velikost plohy ve vech frech na tchto strnkch (me bt upravena nastavenm kurzu a dalmi loklnmi promnnmi)';
$string['configoldpostdays'] = 'Po kolika dnech se bude jakkoliv pspvek povaovat za peten';
$string['configreplytouser'] = 'Kdy je pspvek odesln odbratelm, m email v poli Od: obsahovat adresu autora pspvku? Pjemce tak me odpovdat pmo autorovi emailem a ne pes diskusn frum. I kdy je zde zvolena hodnota \'Ano\', uivatel si mohou ve svch profilech nastavit skrvn svm emailov adresy.';
$string['configshortpost'] = 'Pspvek krat ne tato vloen hodnota (HTML kd se nepot) je povaovn za krtk.';
$string['configtrackreadposts'] = 'Zvolte \'ano\', chcete-li pro kadho uivatele zaznamenvat stav pspvk peteno/nepeteno ';
$string['configusermarksread'] = 'Pi \'ano\' si mus uivatel sami oznait pspvek jako peten. Pi \'ne\' se pspvek po zobrazen automaticky nastav jako peten.';
$string['couldnotadd'] = 'Neznm chyba! Nemohu pidat v pspvek';
$string['couldnotdeleteratings'] = 'Je mi lto, ji ohodnocen pspvek neme bt odstrann';
$string['couldnotdeletereplies'] = 'Je mi lto, pspvek, na kter ji bylo odpovzeno, neme bt odstrann';
$string['couldnotupdate'] = 'Neznm chyba! Nemohu aktualizovat v pspvek';
$string['delete'] = 'Odstranit';
$string['deleteddiscussion'] = 'Tma diskuse bylo odstranno';
$string['deletedpost'] = 'Pspvek byl odstrann';
$string['deletedposts'] = 'Tyto pspvky byly odstranny';
$string['deletesure'] = 'Jste si jist, e chcete odstranit tento pspvek?';
$string['deletesureplural'] = 'Jste si jist, e chcete odstranit tento pspvek a vechny odpovdi na nj? ($a pspvk)';
$string['digestmailheader'] = 'Toto je vas denni souhrn novych prispevku v diskusich na strankach $a->sitename. Chcete-li zmenit nastaveni techto odberu, jdete na $a->userprefs.';
$string['digestmailprefs'] = 'vas uzivatelsky profil';
$string['digestmailsubject'] = '$a: souhrn novych prispevku';
$string['digestsentusers'] = 'Souhrnn emaily spn zaslny $a uivatelm.';
$string['discussion'] = 'Diskuse';
$string['discussionmoved'] = 'Tato diskuse byla pesunuta do \'$a\'.';
$string['discussionname'] = 'Nzev diskuse';
$string['discussions'] = 'Diskuse';
$string['discussionsstartedby'] = 'Diskusi zahjil(a) $a';
$string['discussionsstartedbyrecent'] = 'Diskusi prv zahjil(a) $a';
$string['discussthistopic'] = 'Zobrazit diskusi';
$string['eachuserforum'] = 'Kad me zahjit jedno tma diskuse';
$string['edit'] = 'Upravit';
$string['editedby'] = 'Upraveno: $a->name - $a->date';
$string['editing'] = 'prava';
$string['emptymessage'] = 'Ve vaem pspvku je nco patn. Mon jste nevyplnili nkter povinn daje, nebo piloen soubor byl moc velk.  Vae pravy NEBYLY ULOENY!';
$string['everyonecanchoose'] = 'Kdokoliv si me vybrat odebrn pspvk emailem';
$string['everyoneissubscribed'] = 'Vichni odebraj nov pspvky emailem';
$string['existingsubscribers'] = 'Stvajc odbratel';
$string['forcesubscribe'] = 'Vnutit vem odebrn pspvk emailem';
$string['forcesubscribeq'] = 'Vnutit vem odebrn pspvk emailem?';
$string['forum'] = 'Frum';
$string['forumintro'] = 'vod do diskusnho fra';
$string['forumname'] = 'Nzev fra';
$string['forumposts'] = 'Pspvky ve fru';
$string['forums'] = 'Fra';
$string['forumtype'] = 'Typ fra';
$string['generalforum'] = 'Bn frum pro obecn pouit';
$string['generalforums'] = 'Obecn fra';
$string['inforum'] = 'v $a';
$string['intronews'] = 'Novinky a oznmen';
$string['introsocial'] = 'Oteven frum pro pokec o emkoliv chcete';
$string['introteacher'] = 'Uzaven frum pro uitele kurzu';
$string['lastpost'] = 'Posledn pspvek';
$string['learningforums'] = 'Uebn fra';
$string['markalldread'] = 'Oznait vechny pspvky v tto diskusi jako peten';
$string['markallread'] = 'Oznait vechny pspvky v tomto fru jako peten';
$string['markread'] = 'Oznait jako peten';
$string['markreadbutton'] = 'Oznait jako<br />peten';
$string['markunread'] = 'Oznait jako nepeten';
$string['markunreadbutton'] = 'Oznait jako<br />nepeten';
$string['maxattachmentsize'] = 'Maximln velikost plohy';
$string['maxtimehaspassed'] = 'Je mi lto, vyprel asov limit pro pravu pspvku $a';
$string['message'] = 'Zprva';
$string['missingsearchterms'] = 'Nsledujc termny se vyskytuj pouze ve znakch jazyka HTML:';
$string['modeflatnewestfirst'] = 'Zobrazit odpovdi za sebou (prvn nejnovj)';
$string['modeflatoldestfirst'] = 'Zobrazit odpovdi za sebou (prvn nejstar)';
$string['modenested'] = 'Zobrazit hierarchii odpovd (vetn textu)';
$string['modethreaded'] = 'Zobrazit hierarchii odpovd (pouze osnovu)';
$string['modulename'] = 'Frum';
$string['modulenameplural'] = 'Fra';
$string['more'] = 'vce';
$string['movethisdiscussionto'] = 'Pesunout tuto diskusi do ...';
$string['namenews'] = 'Novinky';
$string['namesocial'] = 'Spolen frum';
$string['nameteacher'] = 'Uitelsk frum';
$string['newforumposts'] = 'Nov pspvky';
$string['nodiscussions'] = 'V tomto fru zatm nejsou dn tmata diskuse';
$string['noguestpost'] = 'Je mi lto, host nemohou pispvat do diskuse';
$string['noguestsubscribe'] = 'Je mi lto, host nemohou odebrat pspvky emailem.';
$string['noguesttracking'] = 'Je mi lto, host si nemohou zapnout oznaovn nepetench pspvk';
$string['nomorepostscontaining'] = 'Nebyly nalezeny dn dal pspvky obsahujc \'$a\'';
$string['nonews'] = 'Dosud nebyly vloeny dn novinky';
$string['noposts'] = 'Bez pspvk';
$string['nopostscontaining'] = 'Nebyly nalezeny dn pspvky obsahujc \'$a\'';
$string['nosubscribers'] = 'V tomto fru zatm nikdo neodebr nov pspvky emailem';
$string['notingroup'] = 'Je mi lto, ale pro prohlen tohoto fra muste bt lenem skupiny.';
$string['notrackforum'] = 'Neoznaovat nepeten pspvky';
$string['nownotsubscribed'] = '$a->name: odebrn pspvk z \'$a->forum\' VYPNUTO.';
$string['nownottracking'] = '$a->name: oznaovn nepetench pspvk v \'$a->forum\' VYPNUTO.';
$string['nowsubscribed'] = '$a->name: odebrn pspvk z \'$a->forum\' ZAPNUTO.';
$string['nowtracking'] = '$a->name: oznaovn nepetench pspvk v \'$a->forum\' ZAPNUTO.';
$string['numposts'] = '$a pspvk';
$string['olderdiscussions'] = 'Star diskuse';
$string['oldertopics'] = 'Star tmata';
$string['openmode0'] = 'Ani nov tmata diskuse, ani odpovdi nejsou povoleny';
$string['openmode1'] = 'Bez tmat diskuse, ale odpovdi jsou povoleny';
$string['openmode2'] = 'Nov tmata diskuse i odpovdi jsou povoleny';
$string['parent'] = 'Ukzat pedchdce';
$string['parentofthispost'] = 'Pedchdce tohoto pspvku';
$string['postadded'] = 'V pspvek byl spn pidn.<p>Na ppadn pravy mte $a .';
$string['postincontext'] = 'Ukzat pspvek v kontextu';
$string['postmailinfo'] = 'Toto je kopie nove zpravy ze stranek $a .
Chcete-li na prispevek odpovedet, nasledujte tento odkaz:';
$string['postrating1'] = 'Vykazuje zejmna INDIVIDULN poznvn';
$string['postrating2'] = 'Rovnomrn samostatn i kolektivn';
$string['postrating3'] = 'Vykazuje zejmna KOLEKTIVN poznvn';
$string['posts'] = 'Pspvky';
$string['posttoforum'] = 'Poslat do fra';
$string['postupdated'] = 'V pspvek byl aktualizovn';
$string['potentialsubscribers'] = 'Odbratel k dispozici';
$string['processingdigest'] = 'Zpracovvm souhrnn email pro uivatele $a';
$string['processingpost'] = 'Zpracovvm pspvek $a';
$string['prune'] = 'Oddlit';
$string['prunedpost'] = 'Z pspvku byla vytvoena nov diskuse';
$string['pruneheading'] = 'Oddlit a pesunout tento pspvek do nov diskuse.';
$string['rate'] = 'Hodnotit';
$string['rating'] = 'Hodnocen';
$string['ratingeveryone'] = 'Kdokoliv me hodnotit pspvky';
$string['ratingno'] = 'Bez hodnocen';
$string['ratingonlyteachers'] = 'Pouze \'$a\' me hodnotit pspvky';
$string['ratingpublic'] = '$a mohou vidt libovoln hodnocen';
$string['ratingpublicnot'] = '$a mohou vidt jen sv hodnocen';
$string['ratings'] = 'Hodnocen';
$string['ratingssaved'] = 'Hodnocen uloeno';
$string['ratingsuse'] = 'Pout hodnocen';
$string['ratingtime'] = 'Omezit hodnocen na pspvky s datumy v tomto rozsahu:';
$string['re'] = 'Re:';
$string['readtherest'] = 'st zbytek tohoto tmatu';
$string['replies'] = 'Odpovdi';
$string['repliesmany'] = '$a odpovd';
$string['repliesone'] = '$a odpov';
$string['reply'] = 'Odpovdt';
$string['replyforum'] = 'Odpovdt do fra';
$string['rsssubscriberssdiscussions'] = 'Zobrazit RSS kanl \'$a\' diskus';
$string['rsssubscriberssposts'] = 'Zobrazit RSS kanl \'$a\' pspvk';
$string['search'] = 'Hledat';
$string['searchdatefrom'] = 'Pspvky mus bt novj ne';
$string['searchdateto'] = 'Pspvky mus bt star ne';
$string['searchforumintro'] = 'Prosm, vlote hledan termny do jednoho nebo vce nsledujcch pol:';
$string['searchforums'] = 'Prohledat fra';
$string['searchfullwords'] = 'Tato slova by se mla vyskytovat jako cel slova';
$string['searchnotwords'] = 'Tato slova by v pspvku NEMLA bt';
$string['searcholderposts'] = 'Prohledat star pspvky...';
$string['searchphrase'] = 'V pspvku se mus vyskytovat pesn tato frze';
$string['searchresults'] = 'Vsledky hledn';
$string['searchsubject'] = 'Tato slova by mla bt v pedmtu pspvku';
$string['searchuser'] = 'Toto jmno by se mlo shodovat s autorem';
$string['searchuserid'] = 'Autorovo Moodle ID ';
$string['searchwhichforums'] = 'Kter fra se maj prohledat';
$string['searchwords'] = 'Tato slova se mohou vykytovat kdekoliv v pspvku';
$string['seeallposts'] = 'Zobrazit vechny pspvky tohoto uivatele';
$string['sendinratings'] = 'Odeslat m posledn hodnocen';
$string['showsubscribers'] = 'Ukzat odbratele';
$string['singleforum'] = 'Prost diskuse';
$string['startedby'] = 'Zahjena';
$string['subject'] = 'Pedmt';
$string['subscribe'] = 'Odebrat nov pspvky emailem';
$string['subscribeall'] = 'Nastavit vem odebrn pspvku emailem';
$string['subscribed'] = 'Pspvky odebrny emailem';
$string['subscribenone'] = 'Odebrat vem odebrn pspvk emailem';
$string['subscribers'] = 'Odbratel';
$string['subscribersto'] = 'Odbratel - \'$a\'';
$string['subscribestart'] = 'Poslej mi emailem kopie pspvk v tomto fru';
$string['subscribestop'] = 'Nechci dostvat emailem kopie pspvk v tomto fru';
$string['subscription'] = 'Odebrn';
$string['subscriptions'] = 'Odebrn';
$string['trackforum'] = 'Oznaovat nepeten pspvky';
$string['tracking'] = 'Oznaovn';
$string['trackingoff'] = 'Vypnuto';
$string['trackingon'] = 'Zapnuto';
$string['trackingoptional'] = 'Voliteln';
$string['trackingtype'] = 'Maj se v tomto fru oznaovat nepeten pspvky?';
$string['unread'] = 'Nepetench';
$string['unreadposts'] = 'Nepetench pspvk';
$string['unreadpostsnumber'] = '$a nepetench pspvk';
$string['unreadpostsone'] = '1 nepeten pspvek';
$string['unsubscribe'] = 'Neodebrat pspvky z tohoto fra emailem';
$string['unsubscribed'] = 'Neodebrno';
$string['unsubscribeshort'] = 'Neodebrat';
$string['yesforever'] = 'Ano, navdy';
$string['yesinitially'] = 'Ano, na zatku';
$string['youratedthis'] = 'Ji jste hodnotili';
$string['yournewtopic'] = 'Vae nov tma diskuse';
$string['yourreply'] = 'Vae odpov';

?>
